==> nextcloud-15.0.0-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/workflowengine/l10n/nl.js <==
OC.L10N.register(
    "workflowengine",
    {
    "Short rule description" : "Korte rolbeschrijving",
    "Add rule" : "Voeg rol toe",
    "Reset" : "Reset",
    "Save" : "Opslaan",
    "Saving…" : "Opslaan...",
    "Group list is empty" : "Groepenlijst is leeg",
    "Unable to retrieve the group list" : "Kan groepenoverzicht niet ophalen",
    "Saved" : "Bewaard",
    "Saving failed:" : "Opslaan mislukt:",
    "Add rule group" : "Groepsrol toevoegen",
    "File MIME type" : "Mimetype bestand",
    "is" : "is",
    "is not" : "is niet",
    "matches" : "komt overeen",
    "does not match" : "komt niet overeen",
    "Example: {placeholder}" : "Bijvoorbeeld: {placeholder}",
    "File name" : "Bestandsnaam",
    "File size (upload)" : "Bestandsgrootte (upload)",
    "less" : "minder",
    "less or equals" : "minder of gelijk",
    "greater or equals" : "groter of gelijk",
    "greater" : "groter",
    "File system tag" : "Bestandssysteem markering",
    "is tagged with" : "is gemarkeerd met",
    "is not tagged with" : "is niet gemarkeerd met",
    "Select tag…" : "Selecteer markering...",
    "Request remote address" : "Extern adres aanvraag",
    "matches IPv4" : "komt overeen met IPv4",
    "does not match IPv4" : "komt niet overeen met IPv4",
    "matches IPv6" : "komt overeen met IPv6",
    "does not match IPv6" : "komt niet overeen met IPv6",
    "Request time" : "Tijdstip aanvraag",
    "between" : "tussen",
    "not between" : "niet tussen",
    "Start" : "Begin",
    "End" : "Einde",
    "Select timezone…" : "Selecteer tijdzone...",
    "Request URL" : "URL aanvraag",
    "Predefined URLs" : "Voorgedefinieerde URL's",
    "Files WebDAV" : "Bestanden WebDAV",
    "Request user agent" : "Useragent aanvraag",
    "Sync clients" : "Synchroniseer clients",
    "Android client" : "Android client",
    "iOS client" : "iOS client",
    "Desktop client" : "Desktop client",
    "Thunderbird & Outlook addons" : "Thunderbird & Outlook addons",
    "User group membership" : "Gebruikersgroep lidmaatschap",
    "is member of" : "is lid van",
    "is not member of" : "is geen lid van",
    "The given operator is invalid" : "De opgegeven operator is ongeldig",
    "The given regular expression is invalid" : "De opgegeven reguliere expressie is ongeldig",
    "The given file size is invalid" : "De opgegeven bestandsgrootte is ongeldig",
    "The given tag id is invalid" : "De opgegeven markerings-id is ongeldig",
    "The given IP range is invalid" : "De opgegeven IP-range is ongeldig",
    "The given IP range is not valid for IPv4" : "De opgegeven IP-range is niet geldig voor IPv4",
    "The given IP range is not valid for IPv6" : "De opgegeven IP-range is niet geldig voor IPv6",
    "The given time span is invalid" : "De opgegeven tijdspanne is ongeldig",
    "The given start time is invalid" : "De opgegeven begintijd is ongeldig",
    "The given end time is invalid" : "De opgegeven eindtijd is ongeldig",
    "The given group does not exist" : "De opgegeven groep bestaat niet",
    "Check %s is invalid or does not exist" : "Controleer: %s is ongeldig of bestaat niet",
    "Operation #%s does not exist" : "Bewerking #%s bestaat niet",
    "Operation %s does not exist" : "Bewerking %s bestaat niet",
    "Operation %s is invalid" : "Bewerking %s is ongeldig",
    "Check %s does not exist" : "Controleer: %s bestaat niet",
    "Check %s is invalid" : "Controleer: %s is ongeldig",
    "Check #%s does not exist" : "Controleer: #%s bestaat niet",
    "Workflow" : "Workflows",
    "Files workflow engine" : "Betanden workflow engine",
    "Open documentation" : "Open documentatie",
    "Loading…" : "Laden..."
},
"nplurals=2; plural=(n != 1);");

==> nextcloud-16.0.1-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/workflowengine/l10n/nl.js <==
OC.L10N.register(
    "workflowengine",
    {
    "File MIME type" : "Mimetype bestand",
    "is" : "is",
    "is not" : "is niet",
    "matches" : "komt overeen",
    "does not match" : "komt niet overeen",
    "Example: {placeholder}" : "Bijvoorbeeld: {placeholder}",
    "File name" : "Bestandsnaam",
    "File size (upload)" : "Bestandsgrootte (upload)",
    "less" : "minder",
    "less or equals" : "minder of gelijk",
    "greater or equals" : "groter of gelijk",
    "greater" : "groter",
    "File system tag" : "Bestandssysteem markering",
    "is tagged with" : "is gemarkeerd met",
    "is not tagged with" : "is niet gemarkeerd met",
    "Select tag…" : "Selecteer markering...",
    "Request remote address" : "Extern adres aanvraag",
    "matches IPv4" : "komt overeen met IPv4",
    "does not match IPv4" : "komt niet overeen met IPv4",
    "matches IPv6" : "komt overeen met IPv6",
    "does not match IPv6" : "komt niet overeen met IPv6",
    "Request time" : "Tijdstip aanvraag",
    "between" : "tussen",
    "not between" : "niet tussen",
    "Start" : "Begin",
    "End" : "Einde",
    "Select timezone…" : "Selecteer tijdzone...",
    "Request URL" : "URL aanvraag",
    "Predefined URLs" : "Voorgedefinieerde URL's",
    "Files WebDAV" : "Bestanden WebDAV",
    "Request user agent" : "Useragent aanvraag",
    "Sync clients" : "Synchroniseer clients",
    "Android client" : "Android client",
    "iOS client" : "iOS client",
    "Desktop client" : "Desktop client",
    "Thunderbird & Outlook addons" : "Thunderbird & Outlook addons",
    "User group membership" : "Gebruikersgroep lidmaatschap",
    "is member of" : "is lid van",
    "is not member of" : "is geen lid van",
    "Short rule description" : "Korte rolbeschrijving",
    "Add rule" : "Voeg rol toe",
    "Reset" : "Reset",
    "Save" : "Opslaan",
    "Saving…" : "Opslaan...",
    "Group list is empty" : "Groepenlijst is leeg",
    "Unable to retrieve the group list" : "Kan groepenoverzicht niet ophalen",
    "Saved" : "Bewaard",
    "Saving failed:" : "Opslaan mislukt:",
    "Add rule group" : "Groepsrol toevoegen",
    "The given operator is invalid" : "De opgegeven operator is ongeldig",
    "The given regular expression is invalid" : "De opgegeven reguliere expressie is ongeldig",
    "The given file size is invalid" : "De opgegeven bestandsgrootte is ongeldig",
    "The given tag id is invalid" : "De opgegeven markerings-id is ongeldig",
    "The given IP range is invalid" : "De opgegeven IP-range is ongeldig",
    "The given IP range is not valid for IPv4" : "De opgegeven IP-range is niet geldig voor IPv4",
    "The given IP range is not valid for IPv6" : "De opgegeven IP-range is niet geldig voor IPv6",
    "The given time span is invalid" : "De opgegeven tijdspanne is ongeldig",
    "The given start time is invalid" : "De opgegeven begintijd is ongeldig",
    "The given end time is invalid" : "De opgegeven eindtijd is ongeldig",
    "The given group does not exist" : "De opgegeven groep bestaat niet",
    "Check %s is invalid or does not exist" : "Controleer: %s is ongeldig of bestaat niet",
    "Operation #%s does not exist" : "Bewerking #%s bestaat niet",
    "Operation %s does not exist" : "Bewerking %s bestaat niet",
    "Operation %s is invalid" : "Bewerking %s is ongeldig",
    "Check %s does not exist" : "Controleer: %s bestaat niet",
    "Check %s is invalid" : "Controleer: %s is ongeldig",
    "Check #%s does not exist" : "Controleer: #%s bestaat niet",
    "Tag management" : "Tagbeheer",
    "Files workflow engine" : "Betanden workflow engine",
    "Open documentation" : "Open documentatie",
    "Loading…" : "Laden...",
    "Workflow" : "Workflows"
},
"nplurals=2; plural=(n != 1);");
